import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { Appsettings } from 'src/app/models/config/appsettings';
import { SoftwareVersion } from 'src/app/models/config/software-version';
import { Theme } from 'src/app/models/view/theme';
import { Themes } from 'src/app/models/view/themes.enum';

@Injectable({
  providedIn: 'root'
})
export class SettingsService {
  appsettings!: Appsettings;

  constructor(
    private http: HttpClient
  ) { }

  loadSettings(): Promise<Appsettings> {
    return new Promise((resolve, reject) => {
      this.http.get<Appsettings>('../../assets/config.json')
        .pipe(catchError(error => {
          reject(error);
          return throwError(() => error);
        })).subscribe(settings => {
          this.appsettings = settings;
          resolve(settings);
        });
    });
  }

  public getApiURL(): string {
    if (!this.appsettings || !this.appsettings.ApiURL) {
      console.error('ApiURL is not set!');
      return '';
    }
    return this.appsettings.ApiURL;
  }

  public getWebVersion(): SoftwareVersion | null {
    if (!this.appsettings || !this.appsettings.WebVersion) {
      console.error('WebVersion is not set!');
      return null;
    }
    const webVersion = new SoftwareVersion(
      this.appsettings.WebVersion.Major,
      this.appsettings.WebVersion.Minor,
      this.appsettings.WebVersion.Micro
    );
    return webVersion;
  }

  public getThemes(): Theme[] | null {
    if (!this.appsettings || !this.appsettings.Themes) {
      console.error('Themes is not set!');
      return null;
    }
    return this.appsettings.Themes;
  }
}

